Rafter
======

Rafter is a Python 3 library providing building blocks for Restfull APIs.
Yes, it's yet another framework trying, again, to solve the same problem!

Rafter is built on top of [Sanic](https://sanic.readthedocs.io/) an
asynchronous and blazing fast HTTP Python framework.

Learn more on **[Rafter Documentation](https://rafter.readthedocs.io/)**.
